Welcome to nbsqueeze
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Creating plots in Jupyter notebooks is great for exploring your data.
The images that are generated by your plotting code are conveniently
stored within the notebook file as base64 encoded text strings. A
downside to this approach is that Jupyter notebooks with many plots
easily become quite large. Uploading such large notebook files to github
and subsequent testing and rendering of such notebooks to produce
documentation soon becomes intolerably slow…

This small Python package `nbsqueeze` is created to reduce the file size
of Jupyter notebooks by extracting embedded images as separate image
files. This open source package available via the Python Package index
<https://pypi.org>.

For documentation and source code see
[github](https://fligt.github.io/nbsqueeze/).
